/* ver.B.b16.07(BLAZE) */


#include "version.h"


VERSION ap_version = {
	"AP.code",
	"gbmx",
	"(C) 2000-2007 Hirohisa Mori and GLOBALBASE Project",
	"ver.B.b16.07(BLAZE)",
	2007,6,27,
	0,
	"GB r64/cr agent ",
};

